<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: editgroupnotifications.php,v 1.6 2004/03/26 17:27:52 yeupou Exp $
#
#  Copyright 2003-2004 (c) Yves Perrin <Yves.Perrin@cern.ch>
#                          Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../../include/pre.php";
require  ($GLOBALS['sys_urlroot'].'/include/vars.php');

require_directory("trackers");

session_require(array('group'=>$group_id,'admin_flags'=>'A'));

if ($update)
{

  group_add_history ('Changed Group Notification Settings','',$group_id);


  $res_new = trackers_data_post_notification_settings($group_id, "bugs");

  $res_new = trackers_data_post_notification_settings($group_id, "support");

  $res_new = trackers_data_post_notification_settings($group_id, "task");

  $res_new = trackers_data_post_notification_settings($group_id, "patch");

}

# update info for page
$res_grp = db_query("SELECT * FROM groups WHERE group_id=$group_id");
if (db_numrows($res_grp) < 1)
{
  exit_no_group();
}
$row_grp = db_fetch_array($res_grp);


site_project_header(array('title'=>_("Editing Notification settings"),'group'=>$group_id,'toptab'=>'ahome'));


# ####################################### General Description

print '
<form action="'.$PHP_SELF.'" method="post">
<input type="hidden" name="group_id" value="'.$group_id.'">
</p>';

 echo '<h3>['.bugs.'] '._("Email Notification Settings").'</h3>';
 if (user_ismember($group_id,'A'))
 {
   trackers_data_show_notification_settings($group_id, 'bugs', 0);
 }

 echo '<h3>['.support.'] '._("Email Notification Settings").'</h3>';
 if (user_ismember($group_id,'A'))
 {
   trackers_data_show_notification_settings($group_id, 'support', 0);
 }

 echo '<h3>['.task.'] '._("Email Notification Settings").'</h3>';
 if (user_ismember($group_id,'A'))
 {
   trackers_data_show_notification_settings($group_id, 'task', 0);
 }

 echo '<h3>['.patch.'] '._("Email Notification Settings").'</h3>';
 if (user_ismember($group_id,'A'))
 {
   trackers_data_show_notification_settings($group_id, 'patch', 0);
 }




echo '
<p><input type="submit" name="update" value="'._("Update").'">
</form>
';

project_admin_footer(array());

?>
